OC.L10N.register(
    "core",
    {
    "Please select a file." : "Favor de seleccionar un archivo.",
    "File is too big" : "El archivo es demasiado grande.",
    "The selected file is not an image." : "El archivo seleccionado no es una imagen.",
    "The selected file cannot be read." : "El archivo seleccionado no se puede leer.",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se subió ningún archivo ",
    "Missing a temporary folder" : "Falta un directorio temporal",
    "Could not write file to disk" : "No se pudo escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "No image or file provided" : "No se especificó un archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "An error occurred. Please contact your admin." : "Se presentó un error. Favor de contactar a su adminsitrador. ",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, favor de intentarlo de nuevo",
    "No crop data provided" : "No se han proporcionado datos del recorte",
    "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
    "Crop is not square" : "El recorte no está cuadrado",
    "State token does not match" : "El token de estado no corresponde",
    "Invalid app password" : "Contraseña de aplicación inválida",
    "Could not complete login" : "No se pudo completar el inicio de sesión",
    "State token missing" : "Falta el token de estado",
    "Your login token is invalid or has expired" : "Su token de inicio de sesión no es válido o ha expirado",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versión comunitaria de Nextcloud ya no está soportada y las notificaciones push son limitadas.",
    "Login" : "Inicio de sesión",
    "Unsupported email length (>255)" : "Longitud de correo electrónico no soportada (>255)",
    "Password reset is disabled" : "Restablecer contraseña se encuentra deshabilitado",
    "Could not reset password because the token is expired" : "No se pudo restablecer la contraseña porque el token ha expirado",
    "Could not reset password because the token is invalid" : "No se pudo restablecer la contraseña porque el token es inválido",
    "Password is too long. Maximum allowed length is 469 characters." : "La contraseña es demasiado larga. La longitud máxima permitida es de 469 caracteres.",
    "%s password reset" : "%s restablecer la contraseña",
    "Password reset" : "Restablecer contraseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haga click en el siguiente botón para restablecer su contraseña. Si no ha solicitado restablecer su contraseña, favor de ignorar este correo. ",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Haga click en el siguiente link para restablecer su contraseña. Si no ha solicitado restablecer la contraseña, favor de ignorar este mensaje. ",
    "Reset your password" : "Restablecer su contraseña",
    "The given provider is not available" : "El proveedor indicado no está disponible",
    "Task not found" : "Tarea no encontrada",
    "Internal error" : "Error interno",
    "Not found" : "No encontrado",
    "Bad request" : "Solicitud inválida",
    "Requested task type does not exist" : "El tipo de tarea solicitada no existe",
    "Necessary language model provider is not available" : "El proveedor de modelo de lenguaje necesario no está disponible",
    "No text to image provider is available" : "No hay proveedores de texto a imagen disponibles",
    "Image not found" : "Imagen no encontrada",
    "No translation provider available" : "No hay proveedor de traducción disponible",
    "Could not detect language" : "No se pudo detectar el idioma",
    "Unable to translate" : "No es posible traducir",
    "Nextcloud Server" : "Servidor Nextcloud",
    "Some of your link shares have been removed" : "Algunos de tus enlaces compartidos han sido eliminados.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un bug de seguridad hemos tenido que eliminar algunos de tus enlaces compartidos. Por favor, accede al link para más información.",
    "The account limit of this instance is reached." : "Se alcanzó el límite de cuentas de esta instancia.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ingrese su clave de suscripción en la aplicación de soporte para aumentar el límite de cuentas. Esto también le otorga todos los beneficios adicionales que ofrece Nextcloud Enterprise y que es altamente recomendado para la operación en empresas.",
    "Learn more ↗" : "Aprender más",
    "Preparing update" : "Preparando actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s ",
    "Repair step:" : "Paso de reparación:",
    "Repair info:" : "Información de reparación:",
    "Repair warning:" : "Advertencia de reparación:",
    "Repair error:" : "Error de reparación:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Por favor, usá el actualizador desde la línea de comandos porque la actualización a través del navegador está deshabilitada en config.php.",
    "Turned on maintenance mode" : "Activar modo mantenimiento",
    "Turned off maintenance mode" : "Desactivar modo mantenimiento",
    "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
    "Updating database schema" : "Actualizando esquema de base de datos",
    "Updated database" : "Base de datos actualizada",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos para %s puede ser actualizado (esto puede tomar mucho tiempo dependiendo del tamaño de la base de datos)",
    "Set log level to debug" : "Establecer nivel de bitacora a depurar",
    "Reset log level" : "Restablecer nivel de bitácora",
    "Starting code integrity check" : "Comenzando verificación de integridad del código",
    "Finished code integrity check" : "Verificación de integridad del código terminó",
    "%s (incompatible)" : "%s (incompatible)",
    "Already up to date" : "Ya está actualizado",
    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
    "Hello {name}" : "Hola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de su búsqueda <script>alert(1)</script></strong>",
    "new" : "nuevo",
    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
    "Update to {version}" : "Actualizar a {version}",
    "An error occurred." : "Se presentó un error.",
    "Please reload the page." : "Favor de volver a cargar la página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulte nuestro comentario  en el foro </a> que cubre este tema. ",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Favor de reportar este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
    "Apps" : "Aplicaciones",
    "More apps" : "Más aplicaciones",
    "No" : "No",
    "Yes" : "Sí",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el link público a su Nextcloud",
    "Searching …" : "Buscando ...",
    "Today" : "Hoy",
    "Date" : "Fecha",
    "Load more results" : "Cargar más resultados",
    "Log in" : "Ingresar",
    "Logging in …" : "Ingresando ...",
    "Account name" : "Nombre de la cuenta",
    "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
    "Please contact your administrator." : "Favor de contactar al administrador.",
    "An internal error occurred." : "Se presentó un error interno.",
    "Please try again or contact your administrator." : "Favor de volver a intentarlo o contacte a su adminsitrador. ",
    "Password" : "Contraseña",
    "Reset password" : "Restablecer contraseña",
    "Back to login" : "Volver para iniciar sesión",
    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Favor de contactar a su adminsitrador. ",
    "New password" : "Nueva contraseña",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Resetting password" : "Restableciendo contraseña",
    "Recommended apps" : "Apps recomendadas",
    "Loading apps …" : "Cargando apps ...",
    "App download or installation failed" : "App descargada o instalación fallida",
    "Skip" : "Saltar",
    "Install recommended apps" : "Instalar apps recomendadas",
    "Settings menu" : "Menú de configuración",
    "Loading your contacts …" : "Cargando sus contactos ... ",
    "Looking for {term} …" : "Buscando {term} ...",
    "Reset search" : "Restablecer búsqueda",
    "Search contacts …" : "Buscar contactos ...",
    "Could not load your contacts" : "No se pudieron cargar tus contactos",
    "No contacts found" : "No se encontraron contactos",
    "Install the Contacts app" : "Instalar app de Contactos",
    "Search" : "Buscar",
    "Forgot password?" : "¿Contraseña olvidada?",
    "Back" : "Atrás",
    "Security warning" : "Advertencia de seguridad",
    "Storage & database" : "Almacenamiento & base de datos",
    "Data folder" : "Carpeta de datos",
    "Install and activate additional PHP modules to choose other database types." : "Instale y active módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
    "For more details check out the documentation." : "Favor de consultar la documentación para más detalles. ",
    "Performance warning" : "Advertencia de desempeño",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas en la base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Favor de especificar el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
    "Database host" : "Servidor de base de datos",
    "Need help?" : "¿Necesita ayuda?",
    "See the documentation" : "Ver la documentación",
    "Choose" : "Seleccionar",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "OK" : "OK",
    "read-only" : "sólo-lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo","{count} conflictos en el archivo"],
    "One file conflict" : "Un conflicto en el archivo",
    "New Files" : "Archivos Nuevos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Cuáles archivos deseas mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si selecciona ambas versiones, se le agregará un número al nombre del archivo copiado.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
    "seconds ago" : "hace segundos",
    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un erorr al cargar la página, recargando en %n segundo","Se presentó un erorr al cargar la página, recargando en %n segundo","Se presentó un erorr al cargar la página, recargando en %n segundo"],
    "Add to a project" : "Agregar a un proyecto",
    "Show details" : "Mostrar detalles",
    "Hide details" : "Ocultar detalles",
    "Rename project" : "Renombrar proyecto",
    "Failed to rename the project" : "Error al renombrar el proyecto",
    "Failed to create a project" : "Error al crear un proyecto",
    "Failed to add the item to the project" : "Error al agregar el elemento al proyecto",
    "New in" : "Nuevo en",
    "View changelog" : "Ver registro de cambios",
    "No action available" : "No hay acciones disponibles",
    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Delete" : "Borrar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "No se encontraron etiquetas",
    "Personal" : "Personal",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso denegado",
    "Page not found" : "Página no encontrada",
    "Back to %s" : "Volver a %s",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubo demasiadas solicitudes desde tu red. Volvé a intentarlo más tarde o ponete en contacto con tu administrador si se trata de un error.",
    "Error" : "Error",
    "Internal Server Error" : "Error interno del servidor",
    "More details can be found in the server log." : "Puede consultar más detalles en la bitácora del servidor. ",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección Remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Rastrear",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Favor de {linkstart}habilitar JavaScript{linkend} y vuelva a cargar la página. ",
    "Skip to main content" : "Saltar al contenido principal",
    "Skip to navigation of app" : "Saltar a la navegación de la app",
    "Go to %s" : "Ir a %s",
    "Get your own free account" : "Obtenga su propia cuenta gratuita",
    "Connect to your account" : "Conéctate a tu cuenta",
    "Grant access" : "Conceder acceso",
    "Account access" : "Acceso a la cuenta",
    "Account connected" : "Cuenta conectada",
    "Previous" : "Anterior",
    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
    "Two-factor authentication" : "Autenticación de dos-factores",
    "Use backup code" : "Usar código de respaldo",
    "Error while validating your second factor" : "Se presentó un error al validar su segundo factor",
    "App update required" : "Se requiere una actualización de la aplicación",
    "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
    "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Favor de asegurarse que la base de datos, la carpeta de configuración y las carpetas de datos hayan sido respaldadas antes de continuar. ",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar que la expiración de tiempo en instalaciones grandes, usted puede ejeuctar el siguiente comando desde su directorio de instalación:",
    "Detailed logs" : "Bitácoras detalladas",
    "Update needed" : "Actualización requerida",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continuo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
    "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte a su administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
    "Show password" : "Mostrar contraseña",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Sólo %s está disponible."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
